@@ -8,21 +8,19 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 
-import numpy
 from gnuradio import gr
-import pmt
-
 import numpy as np
+import pmt
 
 from .eseo_line_decoder import reflect_bytes as reflect
 
+
 class reflect_bytes(gr.basic_block):
-    """
-    docstring for block reflect_bytes
-    """
+    """docstring for block reflect_bytes"""
     def __init__(self):
-        gr.basic_block.__init__(self,
-            name="reflect_bytes",
+        gr.basic_block.__init__(
+            self,
+            name='reflect_bytes',
             in_sig=[],
             out_sig=[])
         self.message_port_register_in(pmt.intern('in'))
@@ -32,12 +30,13 @@ class reflect_bytes(gr.basic_block):
     def handle_msg(self, msg_pmt):
         msg = pmt.cdr(msg_pmt)
         if not pmt.is_u8vector(msg):
-            print("[ERROR] Received invalid message type. Expected u8vector")
+            print('[ERROR] Received invalid message type. Expected u8vector')
             return
-        packet = np.array(pmt.u8vector_elements(msg), dtype = 'uint8')
+        packet = np.array(pmt.u8vector_elements(msg), dtype='uint8')
         packet = np.unpackbits(packet)
         packet = reflect(packet)
         packet = bytes(np.packbits(packet))
-        
-        self.message_port_pub(pmt.intern('out'),
-                              pmt.cons(pmt.PMT_NIL, pmt.init_u8vector(len(packet), packet)))
+
+        self.message_port_pub(
+            pmt.intern('out'),
+            pmt.cons(pmt.PMT_NIL, pmt.init_u8vector(len(packet), packet)))
